Create a structured surface-grid object from a numeric matrix. Rows map to
y, columns map to x, and the matrix values map to z.
Value
A ggwebgl_surface_matrix object accepted by
ggwebgl_layer_surface().
Create a structured surface-grid object from a numeric matrix. Rows map to
y, columns map to x, and the matrix values map to z.
A ggwebgl_surface_matrix object accepted by
ggwebgl_layer_surface().